package MT::Plugin::RichTextFilter;
use strict;

use MT;
require MT::Plugin;
use MT::Template::Context;

our $VERSION = "0.4";

@MT::Plugin::RichTextFilter::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::RichTextFilter({
	name => 'RichTextFilter',
	version => $VERSION,
	description => 'Text Filter for Movable Type\'s Rich Text Editor.',
	author_name => 'Junnama Noda',
	author_link => 'http://junnama.alfasado.net/online/',
});

MT->add_plugin($plugin);
MT::Template::Context->add_global_filter(RichTextFilter => \&_RichTextFilter);

######################################### Mainroutine #########################################

sub _RichTextFilter {
	my($text, $arg, $ctx) = @_;
	$text =~ s/<i>(.*)<\/i>/<em>$1<\/em>/isg;
	$text =~ s/<b>(.*)<\/b>/<strong>$1<\/strong>/isg;
	$text =~ s/<strike>(.*)<\/strike>/<del>$1<\/del>/isg;
	$text =~ s/<u>(.*)<\/u>/<ins>$1<\/ins>/isg;
	$text =~ s/<font(.*?)>(.*?)<\/font>/<span$1>$2<\/span>/isg;
	$text =~ s/<P>/<p>/g;
	$text =~ s/<(a\s|p\s|div|pre|blockquote|li|ul|ol|span)(.*?)>/&tag2xhtml($1, $2 ,0)/eisg;
	$text =~ s/<\/(a|p|div|pre|blockquote|li|ul|ol)>/'<\/'.lc($1).'>'/eig;
	$text =~ s/<(br|hr|img|link|input|col|base|meta|area|param)(.*?)>/&tag2xhtml($1, $2, 1)/eisg;
	$text =~ s/<form\smt:asset-id.*?>(<img\s.*?>)<\/form>/&pick_img($1)/eisg;
	$text =~ s/<form\sclass="mt-enclosure\smt-enclosure-image".*?>(<img\s.*?>)<\/form>/&pick_img($1)/eisg;
	$text =~ s/<span\sclass="mt-enclosure\smt-enclosure-image".*?>(<img\s.*?>)<\/span>/&pick_img($1)/eisg;
	$text =~ s/(<img\s.*style=")(.*)("\s.*?>)/$1.&style2lower($2).$3/eisg;
	$text =~ s/(<img\s.*alt=)(.*?)(\s.*?>)/$1.&add_quot($2).$3/eisg;
	$text =~ s/(<img\s.*class=)(.*?)(\s.*?>)/$1.&add_quot($2).$3/eisg;
	$text =~ s/(<img\s.*width=)(.*?)(\s.*?>)/$1.&add_quot($2).$3/eisg;
	$text =~ s/(<img\s.*height=)(.*?)(\s.*?>)/$1.&add_quot($2).$3/eisg;
	$text =~ s/(<.*?)align=left(>)/$1style="text-align:left"$2/isg;
	$text =~ s/(<.*?)align=center(>)/$1style="text-align:center"$2/isg;
	$text =~ s/(<.*?)align=right(>)/$1style="text-align:right"$2/isg;
	return $text;
}

sub tag2xhtml {
	my $ele = shift;
	my $att = shift;
	my $is_empty = shift;
	$ele = lc($ele);
	$att =~ s/(.*?)(=?".*?")/lc($1).$2/eisg;
	if (($att !~ /.*\/$/) && $is_empty){
		$att .= ' /';
	}
	return '<'.$ele.$att.'>';
}

sub pick_img {
	my $img = shift;
	if ($img =~ /(<img\s.*?)(=".*"\s)(.*?)(=".*"\s)(.*?)(=".*"\s)(.*?)(=".*"\s)(.*?)(=".*"\s)(.*?)(=".*")(.*?>)/gs) {
		$img = lc($1).$2.lc($3).$4.lc($5).$6.lc($7).$8.lc($9).$10.lc($11).$12.$13;
	}
	return $img;
}

sub style2lower {
	my $style = shift;
	$style =~ s/FLOAT:/float:/ig;
	$style =~ s/MARGIN:/margin:/ig;
	return $style;
}

sub add_quot {
	my $att = shift;
	unless ($att =~ /"/) {
		$att = '"'.$att.'"';
	}
	return $att;
}

1;
